# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
from .lab_test_collection_method import LabTestCollectionMethod
from .lab_test_sample_type import LabTestSampleType
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ClientFacingLab(UniversalBaseModel):
    id: int
    slug: str
    name: str
    first_line_address: str
    city: str
    zipcode: str
    collection_methods: typing.List[LabTestCollectionMethod]
    sample_types: typing.List[LabTestSampleType]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class AppointmentType(str, enum.Enum):
    PHLEBOTOMY = "phlebotomy"
    PATIENT_SERVICE_CENTER = "patient_service_center"

    def visit(
        self, phlebotomy: typing.Callable[[], T_Result], patient_service_center: typing.Callable[[], T_Result]
    ) -> T_Result:
        if self is AppointmentType.PHLEBOTOMY:
            return phlebotomy()
        if self is AppointmentType.PATIENT_SERVICE_CENTER:
            return patient_service_center()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class SourceType(str, enum.Enum):
    APP = "app"
    BLE = "ble"
    DEVICE = "device"
    LAB = "lab"
    PROVIDER = "provider"

    def visit(
        self,
        app: typing.Callable[[], T_Result],
        ble: typing.Callable[[], T_Result],
        device: typing.Callable[[], T_Result],
        lab: typing.Callable[[], T_Result],
        provider: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is SourceType.APP:
            return app()
        if self is SourceType.BLE:
            return ble()
        if self is SourceType.DEVICE:
            return device()
        if self is SourceType.LAB:
            return lab()
        if self is SourceType.PROVIDER:
            return provider()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class QueryConfigWeekStartsOn(str, enum.Enum):
    SUNDAY = "sunday"
    MONDAY = "monday"

    def visit(self, sunday: typing.Callable[[], T_Result], monday: typing.Callable[[], T_Result]) -> T_Result:
        if self is QueryConfigWeekStartsOn.SUNDAY:
            return sunday()
        if self is QueryConfigWeekStartsOn.MONDAY:
            return monday()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class EventDestinationPreferencesEnabledItem(str, enum.Enum):
    CLOUD_PUBSUB = "cloud_pubsub"
    RABBITMQ = "rabbitmq"
    SVIX = "svix"
    AZURE_AMQP = "azure_amqp"

    def visit(
        self,
        cloud_pubsub: typing.Callable[[], T_Result],
        rabbitmq: typing.Callable[[], T_Result],
        svix: typing.Callable[[], T_Result],
        azure_amqp: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is EventDestinationPreferencesEnabledItem.CLOUD_PUBSUB:
            return cloud_pubsub()
        if self is EventDestinationPreferencesEnabledItem.RABBITMQ:
            return rabbitmq()
        if self is EventDestinationPreferencesEnabledItem.SVIX:
            return svix()
        if self is EventDestinationPreferencesEnabledItem.AZURE_AMQP:
            return azure_amqp()



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class LabResultsMetadata(UniversalBaseModel):
    age: str
    dob: str
    clia: typing.Optional[str] = pydantic.Field(alias="clia_#", default=None)
    patient: str
    provider: typing.Optional[str] = None
    laboratory: typing.Optional[str] = None
    date_reported: str
    date_collected: typing.Optional[str] = None
    specimen_number: str
    date_received: typing.Optional[str] = None
    status: typing.Optional[str] = None
    interpretation: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import datetime as dt
import typing
from .vital_sleep_stage import VitalSleepStage
from .sleep_cycle_source_provider import SleepCycleSourceProvider
from .sleep_cycle_source_type import SleepCycleSourceType
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class SleepCycle(UniversalBaseModel):
    id: str
    sleep_id: str
    session_start: dt.datetime
    session_end: dt.datetime
    stage_start_offset_second: typing.List[int]
    stage_end_offset_second: typing.List[int]
    stage_type: typing.List[VitalSleepStage]
    time_zone: typing.Optional[str] = None
    source_provider: SleepCycleSourceProvider
    source_type: SleepCycleSourceType
    source_app_id: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class ClientFacingSource(UniversalBaseModel):
    """
    Source summarizes where a sample or a summary is sourced from.
    At minimum, the source provider is always included.
    """

    provider: str = pydantic.Field()
    """
    Provider slug. e.g., `oura`, `fitbit`, `garmin`.
    """

    type: typing.Optional[str] = pydantic.Field(default=None)
    """
    The type of the data source (app or device) by which the summary or the timeseries data were recorded. This defaults to `unknown` when Vital cannot extract or infer that information
    """

    app_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The identifier of the app which recorded this summary. This is only applicable to multi-source providers like Apple Health and Android Health Connect.
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Deprecated. Subject to removal after 1 Jan 2024.
    """

    slug: typing.Optional[str] = pydantic.Field(default=None)
    """
    Deprecated. Use `provider` instead. Subject to removal after 1 Jan 2024.
    """

    logo: typing.Optional[str] = pydantic.Field(default=None)
    """
    Deprecated. Subject to removal after 1 Jan 2024.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .lab_tests_get_orders_request_order_direction import LabTestsGetOrdersRequestOrderDirection
from .lab_tests_get_orders_request_order_key import LabTestsGetOrdersRequestOrderKey

__all__ = ["LabTestsGetOrdersRequestOrderDirection", "LabTestsGetOrdersRequestOrderKey"]



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
from .client_facing_provider import ClientFacingProvider
import datetime as dt
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ProfileInDb(UniversalBaseModel):
    data: typing.Optional[typing.Any] = None
    user_id: str
    source_id: int
    priority_id: typing.Optional[int] = None
    id: str
    source: ClientFacingProvider
    updated_at: typing.Optional[dt.datetime] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing
from .client_facing_shipment import ClientFacingShipment
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class ClientFacingTestkitOrder(UniversalBaseModel):
    """
    Schema for a testkit order in the client facing API.

    To be used as part of a ClientFacingOrder.
    """

    id: str = pydantic.Field()
    """
    The Vital TestKit Order ID
    """

    shipment: typing.Optional[ClientFacingShipment] = pydantic.Field(default=None)
    """
    Shipment object
    """

    created_at: str
    updated_at: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class DelegatedFlowType(str, enum.Enum):
    ORDER_AND_RESULTS_WITH_CUSTOMER_PHYSICIAN_NETWORK = "order_and_results_with_customer_physician_network"
    ORDER_WITH_VITAL_PHYSICIAN_NETWORK = "order_with_vital_physician_network"
    ORDER_AND_RESULTS_WITH_VITAL_PHYSICIAN_NETWORK = "order_and_results_with_vital_physician_network"

    def visit(
        self,
        order_and_results_with_customer_physician_network: typing.Callable[[], T_Result],
        order_with_vital_physician_network: typing.Callable[[], T_Result],
        order_and_results_with_vital_physician_network: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is DelegatedFlowType.ORDER_AND_RESULTS_WITH_CUSTOMER_PHYSICIAN_NETWORK:
            return order_and_results_with_customer_physician_network()
        if self is DelegatedFlowType.ORDER_WITH_VITAL_PHYSICIAN_NETWORK:
            return order_with_vital_physician_network()
        if self is DelegatedFlowType.ORDER_AND_RESULTS_WITH_VITAL_PHYSICIAN_NETWORK:
            return order_and_results_with_vital_physician_network()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class HistoricalPullStatus(str, enum.Enum):
    SUCCESS = "success"
    FAILURE = "failure"
    IN_PROGRESS = "in_progress"
    SCHEDULED = "scheduled"

    def visit(
        self,
        success: typing.Callable[[], T_Result],
        failure: typing.Callable[[], T_Result],
        in_progress: typing.Callable[[], T_Result],
        scheduled: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is HistoricalPullStatus.SUCCESS:
            return success()
        if self is HistoricalPullStatus.FAILURE:
            return failure()
        if self is HistoricalPullStatus.IN_PROGRESS:
            return in_progress()
        if self is HistoricalPullStatus.SCHEDULED:
            return scheduled()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ResultType(str, enum.Enum):
    NUMERIC = "numeric"
    RANGE = "range"
    COMMENT = "comment"

    def visit(
        self,
        numeric: typing.Callable[[], T_Result],
        range: typing.Callable[[], T_Result],
        comment: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ResultType.NUMERIC:
            return numeric()
        if self is ResultType.RANGE:
            return range()
        if self is ResultType.COMMENT:
            return comment()
